[−][src]Enum unicode_types::khmer::Khmer
An enum to represent all characters in the Khmer block.
Variants
LetterKa\u{1780}: 'ក'
LetterKha\u{1781}: 'ខ'
LetterKo\u{1782}: 'គ'
LetterKho\u{1783}: 'ឃ'
LetterNgo\u{1784}: 'ង'
LetterCa\u{1785}: 'ច'
LetterCha\u{1786}: 'ឆ'
LetterCo\u{1787}: 'ជ'
LetterCho\u{1788}: 'ឈ'
LetterNyo\u{1789}: 'ញ'
LetterDa\u{178a}: 'ដ'
LetterTtha\u{178b}: 'ឋ'
LetterDo\u{178c}: 'ឌ'
LetterTtho\u{178d}: 'ឍ'
LetterNno\u{178e}: 'ណ'
LetterTa\u{178f}: 'ត'
LetterTha\u{1790}: 'ថ'
LetterTo\u{1791}: 'ទ'
LetterTho\u{1792}: 'ធ'
LetterNo\u{1793}: 'ន'
LetterBa\u{1794}: 'ប'
LetterPha\u{1795}: 'ផ'
LetterPo\u{1796}: 'ព'
LetterPho\u{1797}: 'ភ'
LetterMo\u{1798}: 'ម'
LetterYo\u{1799}: 'យ'
LetterRo\u{179a}: 'រ'
LetterLo\u{179b}: 'ល'
LetterVo\u{179c}: 'វ'
LetterSha\u{179d}: 'ឝ'
LetterSso\u{179e}: 'ឞ'
LetterSa\u{179f}: 'ស'
LetterHa\u{17a0}: 'ហ'
LetterLa\u{17a1}: 'ឡ'
LetterQa\u{17a2}: 'អ'
IndependentVowelQaq\u{17a3}: 'ឣ'
IndependentVowelQaa\u{17a4}: 'ឤ'
IndependentVowelQi\u{17a5}: 'ឥ'
IndependentVowelQii\u{17a6}: 'ឦ'
IndependentVowelQu\u{17a7}: 'ឧ'
IndependentVowelQuk\u{17a8}: 'ឨ'
IndependentVowelQuu\u{17a9}: 'ឩ'
IndependentVowelQuuv\u{17aa}: 'ឪ'
IndependentVowelRy\u{17ab}: 'ឫ'
IndependentVowelRyy\u{17ac}: 'ឬ'
IndependentVowelLy\u{17ad}: 'ឭ'
IndependentVowelLyy\u{17ae}: 'ឮ'
IndependentVowelQe\u{17af}: 'ឯ'
IndependentVowelQai\u{17b0}: 'ឰ'
IndependentVowelQooTypeOne\u{17b1}: 'ឱ'
IndependentVowelQooTypeTwo\u{17b2}: 'ឲ'
IndependentVowelQau\u{17b3}: 'ឳ'
VowelInherentAq\u{17b4}: '឴'
VowelInherentAa\u{17b5}: '឵'
VowelSignAa\u{17b6}: 'ា'
VowelSignI\u{17b7}: 'ិ'
VowelSignIi\u{17b8}: 'ី'
VowelSignY\u{17b9}: 'ឹ'
VowelSignYy\u{17ba}: 'ឺ'
VowelSignU\u{17bb}: 'ុ'
VowelSignUu\u{17bc}: 'ូ'
VowelSignUa\u{17bd}: 'ួ'
VowelSignOe\u{17be}: 'ើ'
VowelSignYa\u{17bf}: 'ឿ'
VowelSignIe\u{17c0}: 'ៀ'
VowelSignE\u{17c1}: 'េ'
VowelSignAe\u{17c2}: 'ែ'
VowelSignAi\u{17c3}: 'ៃ'
VowelSignOo\u{17c4}: 'ោ'
VowelSignAu\u{17c5}: 'ៅ'
SignNikahit\u{17c6}: 'ំ'
SignReahmuk\u{17c7}: 'ះ'
SignYuukaleapintu\u{17c8}: 'ៈ'
SignMuusikatoan\u{17c9}: '៉'
SignTriisap\u{17ca}: '៊'
SignBantoc\u{17cb}: '់'
SignRobat\u{17cc}: '៌'
SignToandakhiat\u{17cd}: '៍'
SignKakabat\u{17ce}: '៎'
SignAhsda\u{17cf}: '៏'
SignSamyokSannya\u{17d0}: '័'
SignViriam\u{17d1}: '៑'
SignCoeng\u{17d2}: '្'
SignBathamasat\u{17d3}: '៓'
SignKhan\u{17d4}: '។'
SignBariyoosan\u{17d5}: '៕'
SignCamnucPiiKuuh\u{17d6}: '៖'
SignLekToo\u{17d7}: 'ៗ'
SignBeyyal\u{17d8}: '៘'
SignPhnaekMuan\u{17d9}: '៙'
SignKoomuut\u{17da}: '៚'
CurrencySymbolRiel\u{17db}: '៛'
SignAvakrahasanya\u{17dc}: 'ៜ'
SignAtthacan\u{17dd}: '៝'
DigitZero\u{17e0}: '០'
DigitOne\u{17e1}: '១'
DigitTwo\u{17e2}: '២'
DigitThree\u{17e3}: '៣'
DigitFour\u{17e4}: '៤'
DigitFive\u{17e5}: '៥'
DigitSix\u{17e6}: '៦'
DigitSeven\u{17e7}: '៧'
DigitEight\u{17e8}: '៨'
DigitNine\u{17e9}: '៩'
SymbolLekAttakSon\u{17f0}: '៰'
SymbolLekAttakMuoy\u{17f1}: '៱'
SymbolLekAttakPii\u{17f2}: '៲'
SymbolLekAttakBei\u{17f3}: '៳'
SymbolLekAttakBuon\u{17f4}: '៴'
SymbolLekAttakPram\u{17f5}: '៵'
SymbolLekAttakPramDashMuoy\u{17f6}: '៶'
SymbolLekAttakPramDashPii\u{17f7}: '៷'
SymbolLekAttakPramDashBei\u{17f8}: '៸'
SymbolLekAttakPramDashBuon\u{17f9}: '៹'
Methods
impl Khmer[src]
pub fn new() -> Self[src]
The character with the lowest index in this unicode block
pub fn name(&self) -> String[src]
The character's name, in sentence case